==> jc-1.4.0.tar.gz: javax/swing/JSpinner__24StubEditor.h <==
// public class javax.swing.JSpinner$StubEditor

// class file dependencies
// @dep_class d547e55bb64f2ca8 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6c83b58ef8abc63e javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 2203650676426a67 javax_swing_JSpinner__24StubEditor

// header file dependencies
// @dep_header javax_swing_JLabel

#include "javax/swing/JLabel.h"

#ifndef _JC_javax_swing_JSpinner__24StubEditor_H_
#define _JC_javax_swing_JSpinner__24StubEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JButton$object;
struct _jc_javax_swing_JLabel$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JSpinner__24StubEditor$sub_refs	_jc_javax_swing_JSpinner__24StubEditor$sub_refs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs	_jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$refs	_jc_javax_swing_JSpinner__24StubEditor$refs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$nonrefs	_jc_javax_swing_JSpinner__24StubEditor$nonrefs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$object	_jc_javax_swing_JSpinner__24StubEditor$object;

typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vmethods	_jc_javax_swing_JSpinner__24StubEditor$vmethods;
typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vtable	_jc_javax_swing_JSpinner__24StubEditor$vtable;
typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vtype	_jc_javax_swing_JSpinner__24StubEditor$vtype;

// Constructors
extern void _jc_javax_swing_JSpinner__24StubEditor$method$_init$e4c5e17f45ff705d(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_JSpinner$object *);

// Virtual methods
extern void _jc_javax_swing_JSpinner__24StubEditor$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_event_ChangeEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSpinner__24StubEditor$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JSpinner__24StubEditor$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_event_ChangeEvent$object *);
};

// Vtable
struct _jc_javax_swing_JSpinner__24StubEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_JSpinner__24StubEditor$vmethods	javax_swing_JSpinner__24StubEditor;
};

// Vtype
struct _jc_javax_swing_JSpinner__24StubEditor$vtype {
	_jc_type			type;
	_jc_javax_swing_JSpinner__24StubEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24StubEditor$sub_refs {
	struct _jc_javax_swing_JLabel$object	*label;
	struct _jc_javax_swing_JButton$object	*up;
	struct _jc_javax_swing_JButton$object	*down;
	struct _jc_javax_swing_JSpinner$object	*spinner;
};

// Reference instance fields (object)
struct _jc_javax_swing_JSpinner__24StubEditor$refs {
    _jc_javax_swing_JSpinner__24StubEditor$sub_refs	javax_swing_JSpinner__24StubEditor;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSpinner__24StubEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs	javax_swing_JSpinner__24StubEditor;
};

// Object instance structure
struct _jc_javax_swing_JSpinner__24StubEditor$object {
	_jc_javax_swing_JSpinner__24StubEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSpinner__24StubEditor$vtype	*vtype;
	_jc_javax_swing_JSpinner__24StubEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSpinner__24StubEditor$vtype _jc_javax_swing_JSpinner__24StubEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSpinner__24StubEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSpinner__24StubEditor$class_object;

#endif	/* _JC_javax_swing_JSpinner__24StubEditor_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JSpinner__24StubEditor.h <==
// public class javax.swing.JSpinner$StubEditor

// class file dependencies
// @dep_class 5a2bf6e9db456f42 java_awt_Component
// @dep_class a9ec1dfd683af396 java_awt_Container
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c84352ee73c7cec1 javax_swing_JComponent
// @dep_class d7ef9fe7ff454b0d javax_swing_JLabel
// @dep_class 2203650676426a67 javax_swing_JSpinner__24StubEditor

// header file dependencies
// @dep_header javax_swing_JLabel

#include "javax/swing/JLabel.h"

#ifndef _JC_javax_swing_JSpinner__24StubEditor_H_
#define _JC_javax_swing_JSpinner__24StubEditor_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JButton$object;
struct _jc_javax_swing_JLabel$object;
struct _jc_javax_swing_JSpinner$object;
struct _jc_javax_swing_event_ChangeEvent$object;

// Typedefs
typedef struct _jc_javax_swing_JSpinner__24StubEditor$sub_refs	_jc_javax_swing_JSpinner__24StubEditor$sub_refs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs	_jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$refs	_jc_javax_swing_JSpinner__24StubEditor$refs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$nonrefs	_jc_javax_swing_JSpinner__24StubEditor$nonrefs;
typedef struct _jc_javax_swing_JSpinner__24StubEditor$object	_jc_javax_swing_JSpinner__24StubEditor$object;

typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vmethods	_jc_javax_swing_JSpinner__24StubEditor$vmethods;
typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vtable	_jc_javax_swing_JSpinner__24StubEditor$vtable;
typedef const struct _jc_javax_swing_JSpinner__24StubEditor$vtype	_jc_javax_swing_JSpinner__24StubEditor$vtype;

// Constructors
extern void _jc_javax_swing_JSpinner__24StubEditor$method$_init$e4c5e17f45ff705d(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_JSpinner$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JSpinner__24StubEditor$method$stateChanged$4d8b57b35708ef83(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JSpinner__24StubEditor$method_info$stateChanged$4d8b57b35708ef83;

// Virtual methods structure
struct _jc_javax_swing_JSpinner__24StubEditor$vmethods {
	void	(*stateChanged$4d8b57b35708ef83)(_jc_env *, struct _jc_javax_swing_JSpinner__24StubEditor$object *, struct _jc_javax_swing_event_ChangeEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JSpinner__24StubEditor$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_Component$vmethods	java_awt_Component;
	_jc_java_awt_Container$vmethods	java_awt_Container;
	_jc_javax_swing_JComponent$vmethods	javax_swing_JComponent;
	_jc_javax_swing_JLabel$vmethods	javax_swing_JLabel;
	_jc_javax_swing_JSpinner__24StubEditor$vmethods	javax_swing_JSpinner__24StubEditor;
};

// Vtype
struct _jc_javax_swing_JSpinner__24StubEditor$vtype {
	_jc_type			type;
	_jc_javax_swing_JSpinner__24StubEditor$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24StubEditor$sub_refs {
	struct _jc_javax_swing_JLabel$object	*label;
	struct _jc_javax_swing_JButton$object	*up;
	struct _jc_javax_swing_JButton$object	*down;
	struct _jc_javax_swing_JSpinner$object	*spinner;
};

// Reference instance fields (object)
struct _jc_javax_swing_JSpinner__24StubEditor$refs {
    _jc_javax_swing_JSpinner__24StubEditor$sub_refs	javax_swing_JSpinner__24StubEditor;
    _jc_javax_swing_JLabel$sub_refs	javax_swing_JLabel;
    _jc_javax_swing_JComponent$sub_refs	javax_swing_JComponent;
    _jc_java_awt_Container$sub_refs	java_awt_Container;
    _jc_java_awt_Component$sub_refs	java_awt_Component;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JSpinner__24StubEditor$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_Component$sub_nonrefs	java_awt_Component;
    _jc_java_awt_Container$sub_nonrefs	java_awt_Container;
    _jc_javax_swing_JComponent$sub_nonrefs	javax_swing_JComponent;
    _jc_javax_swing_JLabel$sub_nonrefs	javax_swing_JLabel;
    _jc_javax_swing_JSpinner__24StubEditor$sub_nonrefs	javax_swing_JSpinner__24StubEditor;
};

// Object instance structure
struct _jc_javax_swing_JSpinner__24StubEditor$object {
	_jc_javax_swing_JSpinner__24StubEditor$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JSpinner__24StubEditor$vtype	*vtype;
	_jc_javax_swing_JSpinner__24StubEditor$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JSpinner__24StubEditor$vtype _jc_javax_swing_JSpinner__24StubEditor$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JSpinner__24StubEditor, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JSpinner__24StubEditor$class_object;

#endif	/* _JC_javax_swing_JSpinner__24StubEditor_H_ */
